@@ -102,7 +102,7 @@ pfGridding <- function(data, cell_sizex=NULL,
                        sea_mask=TRUE,
                        other_mask=NULL,
                        verbose=TRUE) {
-
+  
   ## pfTransform object
   if (class(data) == "pfTransform") {
     data <- data.frame(
@@ -115,28 +115,30 @@ pfGridding <- function(data, cell_sizex=NULL,
     ## Remove extreme outliers i.e. 3*sd (sometimes happens... why? probably baseperiod related)
     data <- data[data[, 4] < 3 * sd(data[, 4]) & data[, 4] > -(3 * sd(data[, 4])), ]
   }
-
-
+  
+  
   ## Limit the input to age+-time_buffer
   if (is.null(time_buffer)) time_buffer <- 500
   data <- data[data[, 3] >= age - time_buffer & data[, 3] <= age + time_buffer, ]
-
-
+  
+  
   # source("/Users/Olivier/Documents/BorealTreeCover/final/triCube.R")
   ## Load countries with lakes from http://www.naturalearthdata.com/downloads/10m-cultural-vectors/
   # load(file="/Users/Olivier/Documents/BorealTreeCover/final/world_map.rda")
   longlat <- "+proj=longlat|+proj = longlat|+proj =longlat|+proj= longlat|+proj=longlat"
-
+  
   if (is.null(proj4)) {
     proj4 <- "+proj=robin +lon_0=0 +x_0=0 +y_0=0 +ellps=WGS84 +datum=WGS84 +units=m +no_defs"
   }
-
+  
   xy <- cbind(data[, 1], data[, 2])
-
+  
   ### LOAD DEM if required
   if (is.null(elevation_buffer) == FALSE | sea_mask == TRUE) {
-    cat("Preparing data and loading DEM...")
-    cat("\n")
+    if(verbose == TRUE){
+      cat("Preparing data and loading DEM...")
+      cat("\n")
+    }
     ## dem is GMTED2010
     dem <- NULL
     data(dem, envir = environment())
@@ -146,25 +148,30 @@ pfGridding <- function(data, cell_sizex=NULL,
     # plot(dem1)
   }
   ###
-
+  
   if (grepl(longlat, proj4) == FALSE) {
-    dat2 <- data.frame(project(xy, proj4))
+    dat2 <- data.frame(rgdal::project(xy, proj4))
   } else {
     dat2 <- data.frame(xy)
   }
-
+  
   colnames(dat2) <- c("x", "y")
   if (is.null(raster_extent)) {
     e <- extent(c(round(range(dat2$x) * 2) / 2, round(range(dat2$y) * 2) / 2))
   } else {
-    toto <- cbind(
-      x = c(raster_extent[c(1, 1, 2, 2)], raster_extent[1] + (raster_extent[2] - raster_extent[1]) / 2),
-      y = c(raster_extent[c(3, 4, 3, 4)], raster_extent[3])
-    )
-    e <- extent(project(toto, proj4))
+    if(grepl("longlat",proj4)){
+      e=extent(raster_extent)
+    }else{
+      toto <- cbind(
+        x = c(raster_extent[c(1, 1, 2, 2)], raster_extent[1] + (raster_extent[2] - raster_extent[1]) / 2),
+        y = c(raster_extent[c(3, 4, 3, 4)], raster_extent[3])
+      )
+      e <- extent(project(toto, proj4))
+    }
   }
-
-
+  
+  
+  
   # Cell sizes
   if (is.null(cell_size)) {
     if (is.null(cell_sizex)) cell_sizex <- 200000
@@ -173,15 +180,16 @@ pfGridding <- function(data, cell_sizex=NULL,
     cell_sizex <- cell_size
     cell_sizey <- cell_size
   }
-  # Number of rows and columns
+  # Number of rows and columns (WORK only if coords are in m)
+  
   nc <- ceiling((e@xmax - e@xmin) / cell_sizex)
   nr <- ceiling((e@ymax - e@ymin) / cell_sizey)
-
+  
   r <- raster(e, ncol = nc, nrow = nr, resolution = c(cell_sizex, cell_sizey)) # Empty raster
   projection(r) <- proj4
-
+  
   if (is.null(distance_buffer)) distance_buffer <- 300000
-
+  
   ## Elevation stuff (median elevation in each predicted cell)
   if (is.null(elevation_buffer) == FALSE | sea_mask == TRUE) {
     temp <- rasterToPoints(dem1)
@@ -199,19 +207,21 @@ pfGridding <- function(data, cell_sizex=NULL,
   } else {
     dat1 <- as.data.frame(rasterToPoints(r))
   }
-
-
+  
+  
   ## Initiate a percentage counter
   if (verbose == TRUE) {
-    percent <- seq(10, 100, by = 10)
+    percent <- seq(1, 100, by = 1)
     values <- round(percent * length(dat1[, 1]) / 100)
     cat("Spatio-temporal weighted interpolation...")
     cat("\n")
-    cat("Percentage done: ")
+    #cat("Percentage done: ")
   }
-
+  
   # ptm <- proc.time()
-
+  if(verbose== TRUE){
+    pb   <- txtProgressBar(1, length(dat1[, 1]), style=3)}
+  
   ## Main loop time--distance weighting
   dat1[, 3] <- c()
   for (i in 1:length(dat1[, 1])) {
@@ -220,9 +230,9 @@ pfGridding <- function(data, cell_sizex=NULL,
     } else {
       d <- pointDistance(dat1[i, 1:2], dat2, longlat = FALSE)
     }
-
+    
     d <- cbind(dat2, data[, 3], d, triCube(d, distance_buffer))
-
+    
     ## Elevation range search
     if (is.null(elevation_buffer) == FALSE) {
       elev2 <- extract(dem1, d[, 1:2])
@@ -233,7 +243,7 @@ pfGridding <- function(data, cell_sizex=NULL,
       d[is.na(d[, 6]), 5] <- 0
     }
     d1 <- d[d[, 5] != 0, ]
-
+    
     ## Time weight
     d1 <- cbind(d1, triCube(age - d1[, 3], time_buffer))
     # head(d)
@@ -242,10 +252,10 @@ pfGridding <- function(data, cell_sizex=NULL,
     } else {
       colnames(d1) <- c("x", "y", "age", "dist", "dweight", "tweight")
     }
-
+    
     d1$weight <- d1$dweight * d1$tweight
     d1$data <- data[d[, 5] != 0, 4]
-
+    
     ## Combine time and distance weights
     threshold <- 0.5
     if (sum(d1$weight, na.rm = TRUE) > threshold) {
@@ -253,18 +263,23 @@ pfGridding <- function(data, cell_sizex=NULL,
     } else {
       dat1[i, 3] <- NA
     }
-
+    
     ## Verbose
-    if (i %in% values & verbose == TRUE) {
-      cat(percent[values == i], " ", sep = "")
+    if(verbose== TRUE){
+      Sys.sleep(0.00002)
+      if (i %in% values) {
+        setTxtProgressBar(pb, i)
+      }
     }
-    # cat(i," ")
+    
+  }
+  if(verbose== TRUE){
+    cat("\n")
   }
-
   r1 <- rasterize(dat1[, 1:2], r, dat1[, 3], fun = mean) # Fill raster with mean value
   #   plot(r1)
-
-
+  
+  
   ## SEA MASK
   if (sea_mask == TRUE) {
     r2 <- temp2 < (-1000) ## sea is now 1
@@ -284,13 +299,13 @@ pfGridding <- function(data, cell_sizex=NULL,
     # !!!!!!MASK
     r1 <- (r1 - r2)
   }
-
+  
   # plot(r1-r2)
-
+  
   dat1 <- as.data.frame(rasterToPoints(r1))
-
+  
   ## End of DATA part --------------------------------------------------------------------
-
+  
   out <- list(raster = r1, df = dat1, proj4 = proj4, extent = e, points = dat2, res = c(cell_sizex, cell_sizey))
   class(out) <- "pfGridding"
   return(out)
@@ -357,12 +372,12 @@ plot.pfGridding <- function(x, continuous=TRUE,
   if (!requireNamespace("RColorBrewer", quietly = TRUE)) {
     install.packages("RColorBrewer")
   }
-
+  
   y <- long <- lat <- group <- res1 <- res2 <- NULL ##  no visible binding for global variable 'y' ?
-
+  
   x$df <- as.data.frame(rasterToPoints(x$raster))
   x$df[, 3][is.infinite(x$df[, 3])] <- NA # define Inf as NA
-
+  
   # Define classes for colors
   if (is.null(col_class)) {
     if (anomalies == TRUE) {
@@ -386,15 +401,15 @@ plot.pfGridding <- function(x, continuous=TRUE,
     breaks <- col_class
   }
   # End of options
-
+  
   ## Define color limils
   if (is.null(col_lim)) {
     col_lim <- c(floor(min(x$df$layer, na.rm = TRUE)), ceiling(max(x$df$layer, na.rm = TRUE)))
   }
-
+  
   x$df <- cbind(x$df, class = cut(x$df$layer, breaks))
   #   data=na.omit(data)
-
+  
   coast <- NULL ## Load coast data and transform
   data(coast, envir = environment())
   coast <- coast[coast$X <= 180, ]
@@ -402,43 +417,43 @@ plot.pfGridding <- function(x, continuous=TRUE,
   xy <- cbind(coast[, 2], coast[, 1])
   longlat <- "+proj=longlat|+proj = longlat|+proj =longlat|+proj= longlat|+proj=longlat"
   if (grepl(longlat, x$proj4) == FALSE) {
-    coast <- data.frame(project(xy, x$proj4))
+    coast <- data.frame(rgdal::project(xy, x$proj4))
   } else {
     coast <- data.frame(xy)
   }
-
-
+  
+  
   colnames(coast) <- c("x", "y")
-
-
+  
+  
   countries <- NULL ## Load countries data and transform
   data(countries, envir = environment())
   # plot((coast$X),(coast$Y),type="l")
   xy <- cbind(countries$x, countries$y)
   xy <- xy[xy[, 1] <= 180, ]
-  countries <- data.frame(project(xy, x$proj4))
+  countries <- data.frame(rgdal::project(xy, x$proj4))
   colnames(countries) <- c("x", "y")
-
-
+  
+  
   ## LIMITS
   if (is.null(xlim)) {
     xplus <- (x$extent@xmax - x$extent@xmin) * empty_space / 100
     xlim <- c(x$extent@xmin - xplus, x$extent@xmax + xplus)
   }
-
+  
   if (is.null(ylim)) {
     yplus <- (x$extent@ymax - x$extent@ymin) * empty_space / 100
     ylim <- c(x$extent@ymin - yplus, x$extent@ymax + yplus)
   }
-
+  
   ## Crop coast using limits
-  coast <- coast[coast$x > xlim[1] - 8000000 & coast$x < xlim[2] + 8000000 &
-    coast$y > ylim[1] - 8000000 & coast$y < ylim[2] + 8000000, ]
+  #  coast <- coast[coast$x > xlim[1] - 8000000 & coast$x < xlim[2] + 8000000 &
+  #  coast$y > ylim[1] - 8000000 & coast$y < ylim[2] + 8000000, ]
   # plot(coast[,1],coast[,2],type="l")
-
+  
   x$points <- data.frame(na.omit(x$points))
   colnames(x$points) <- c("x", "y")
-
+  
   if (anomalies == TRUE) {
     if (cpal == "YlGn") {
       cpal <- "RdBu"
@@ -447,9 +462,9 @@ plot.pfGridding <- function(x, continuous=TRUE,
   } else {
     pal <- RColorBrewer::brewer.pal(9, cpal)
   }
-
+  
   testcol <- colorRampPalette(pal)
-
+  
   #   ## LIMITS
   #   if(is.null(xlim)){
   #     xplus=(x$extent@xmax-x$extent@xmin)*0.1
@@ -458,7 +473,7 @@ plot.pfGridding <- function(x, continuous=TRUE,
   #   if(is.null(ylim)){
   #     yplus=(x$extent@ymax-x$extent@ymin)*0.1
   #     ylim=c(x$extent@ymin-yplus,x$extent@ymax+yplus)}
-
+  
   ## SAME COLORS
   if (continuous == FALSE & is.numeric(col_class) & length(col_class) > 1) {
     options(warn = -1)
@@ -474,12 +489,12 @@ plot.pfGridding <- function(x, continuous=TRUE,
   if (cpal == "Greys") {
     pale <- rev(testcol(length(levels(x$df$class)) + 1)[1:(length(levels(x$df$class)))])
   }
-
-  # display.brewer.pal(12,"Spectral")
+  
+  # display.brewer.pal(12,"RdYlBu")
   # pal=c(pal[9],pal[8],pal[6:1])
   ## On fait une carte avec ggplot2
   # pdf(file="/Users/Olivier/Desktop/x$dfMap.pdf",height=6,width=9)
-
+  
   ## Add shp to the plot
   if (is.null(add) == FALSE) {
     theclass <- lapply(add@data, class)
@@ -492,11 +507,11 @@ plot.pfGridding <- function(x, continuous=TRUE,
     add.points <- ggplot2::fortify(add, region = "id")
     add.df <- plyr::join(add.points, add@data, by = "id")
   }
-
+  
   ##
   x$df$res1 <- x$res[1]
   x$df$res2 <- x$res[2]
-
+  
   ## Plot only points
   if (points == "Only") {
     p <- ggplot(x$df) +
@@ -517,7 +532,7 @@ plot.pfGridding <- function(x, continuous=TRUE,
       if (cpal == "Greys") {
         p <- p + geom_polygon(data = coast, aes(x = x, y = y), colour = "black", fill = "white")
       } else {
-        p <- p + geom_polygon(data = coast, aes(x = x, y = y), colour = "grey80", fill = "grey80")
+        p <- p + geom_polygon(data = coast, aes(x = x, y = y), colour = "black", fill = "white")
       }
       p <- p + geom_tile(data = x$df, aes(x = x, y = y, fill = class, width = res1, height = res2)) +
         scale_fill_manual(values = pale, name = "") +
@@ -532,9 +547,10 @@ plot.pfGridding <- function(x, continuous=TRUE,
       }
     } else {
       p <- ggplot(x$df) +
-        geom_polygon(data = coast, aes(x = x, y = y), colour = "grey80", fill = "grey80") +
+        geom_polygon(data = coast, aes(x = x, y = y), colour = "black", fill = "white") +
         geom_tile(data = x$df, aes(x = x, y = y, fill = layer, width = res1, height = res2)) +
-        scale_fill_gradient2(high = pal[9], low = pal[1], mid = "white", limits = col_lim) +
+        #scale_fill_gradient2(high = pal[9], low = pal[1], mid = "white", limits = col_lim) +
+        scale_fill_gradientn(colors = pale, name = "") +
         coord_cartesian(xlim = xlim, ylim = ylim) + xlab("Longitude") + ylab("Latitude") +
         theme_bw(base_size = 16)
       if (is.null(add) == FALSE) {
@@ -542,11 +558,11 @@ plot.pfGridding <- function(x, continuous=TRUE,
       }
       if (points == TRUE) p <- p + geom_point(data = x$points, aes(x = x, y = y), colour = "grey40")
       if (plot_countries == TRUE) {
-        p <- p + geom_path(data = countries, aes(x = x, y = y), colour = "white")
+        p <- p + geom_path(data = countries, aes(x = x, y = y), colour = "black")
       }
     }
   }
-
+  
   p
   if (is.null(file) == FALSE) {
     projection(x$raster) <- sp::CRS(x$proj4)
